diff --git a/httpdocs/.idea/.gitignore b/httpdocs/.idea/.gitignore
new file mode 100644
index 0000000..73f69e0
--- /dev/null
+++ b/httpdocs/.idea/.gitignore
@@ -0,0 +1,8 @@
+# Default ignored files
+/shelf/
+/workspace.xml
+# Datasource local storage ignored files
+/dataSources/
+/dataSources.local.xml
+# Editor-based HTTP Client requests
+/httpRequests/
diff --git a/httpdocs/.idea/httpdocs.iml b/httpdocs/.idea/httpdocs.iml
new file mode 100644
index 0000000..c956989
--- /dev/null
+++ b/httpdocs/.idea/httpdocs.iml
@@ -0,0 +1,8 @@
+
+
Give access to files";
- $this->chatController->publishMessage($message, $user, $sala);
- return new JsonResponse("success", 200);
- }
- public function giveAccessToFilesAction($id){
- if(!$this->isXmlHttpRequest()){
- throw new AccessDeniedHttpException();
- }
- $user = $this->getUser();
- if(!($user instanceof Trainer)){
- throw new AccessDeniedHttpException();
- }
- $em = $this->getDoctrine()->getManager();
- $fa = $em->getReference(User::class, $id);
- if(!($fa instanceof FinancialActor)){
- throw new AccessDeniedHttpException();
- }
- $user->addFinancial($fa);
- $em->persist($user);
- $em->flush();
- $modalBody = "You have successfully shared your documents with ".$fa->getNombreCompleto();
- $modalTitle = "Congratulations!!!";
- return $this->renderWithExtraParams('listajaxactions/modal_content.html.twig', [
- 'modalTitle' => $modalTitle,
- 'modalBody' => $modalBody,
- ], null);
- }
-
-}
diff --git a/httpdocs/src/Controller/Admin/TrainerAdminController.php.save.1 b/httpdocs/src/Controller/Admin/TrainerAdminController.php.save.1
deleted file mode 100644
index 603617e..0000000
--- a/httpdocs/src/Controller/Admin/TrainerAdminController.php.save.1
+++ /dev/null
@@ -1,91 +0,0 @@
-chatController = $chatController;
- }
-
-
- public function contactarAjaxAction($id){
- $user = $this->getUser();
- if(!($user instanceof FinancialActor) && !($user instanceof Bso)){
- throw new AccessDeniedHttpException();
- }
- $em = $this->getDoctrine()->getManager();
- $ge = $em->getReference(User::class, $id);
- if(!($ge instanceof Trainer)){
- throw new AccessDeniedHttpException();
- }
- $sala = new Sala();
- $sala->addUser($user);
- $sala->addUser($ge);
- $sala->setDenominacion('Contacto');
- $lastAccess = new SalaLastAccess();
- $lastAccess->setSala($sala);
- $lastAccess->setUser($ge);
- $lastAccess->setLastAccess(new \DateTime("1970-01-01"));
- $em->persist($lastAccess);
- $sala->addSalaLastAccess($lastAccess);
- $em->persist($sala);
- $ge->addContacto($user);
- $user->addContacto($ge);
- $em->persist($ge);
- $em->persist($user);
- $em->flush();
- $route = $this->generateUrl('admin_app_trainer_giveAccessToFiles', ['id'=> $user->getId()]);
- $message = "A financial actor would like to talk to you.
Give access to files";
- $message = "A financial actor would like to talk to you.
Give access to files";
- $this->chatController->publishMessage($message, $user, $sala);
- return new RedirectResponse($this->generateUrl('sonata_admin_dashboard'));
-
- return new JsonResponse("success", 200);
- }
- public function giveAccessToFilesAction($id){
- if(!$this->isXmlHttpRequest()){
- throw new AccessDeniedHttpException();
- }
- $user = $this->getUser();
- if(!($user instanceof GreenEntrepreneur)){
- throw new AccessDeniedHttpException();
- }
- $em = $this->getDoctrine()->getManager();
- $fa = $em->getReference(User::class, $id);
- if(!($fa instanceof FinancialActor)){
- throw new AccessDeniedHttpException();
- }
- $user->addFinancial($fa);
- $em->persist($user);
- $em->flush();
- $modalBody = "You have successfully shared your documents with ".$fa->getNombreCompleto();
- $modalTitle = "Congratulations!!!";
- return $this->renderWithExtraParams('listajaxactions/modal_content.html.twig', [
- 'modalTitle' => $modalTitle,
- 'modalBody' => $modalBody,
- ], null);
- }
-
-}
diff --git a/httpdocs/src/Controller/Admin/WorkShopsAdminController.php b/httpdocs/src/Controller/Admin/WorkShopsAdminController.php
index f7610b1..d902bf9 100644
--- a/httpdocs/src/Controller/Admin/WorkShopsAdminController.php
+++ b/httpdocs/src/Controller/Admin/WorkShopsAdminController.php
@@ -5,7 +5,7 @@ declare(strict_types=1);
namespace App\Controller\Admin;
use App\Entity\Convocatoria;
-use App\Entity\GreenEntrepreneur;
+use App\Entity\Licitador;
use App\Entity\Procesos;
use App\Twig\Extension\JsonDecode;
use phpDocumentor\Reflection\DocBlock\Serializer;
@@ -67,7 +67,7 @@ final class WorkShopsAdminController extends IsOwnerCRUDController
return new Response ($output);
}
try{
- $entrepreneurs = $doctrine->getRepository(GreenEntrepreneur::class)
+ $entrepreneurs = $doctrine->getRepository(Licitador::class)
->findByConvocatoria($convocatoria, $proceso);
}catch(\Exception $e){
throw new BadRequestHttpException('Hay algún error en la petición');
diff --git a/httpdocs/src/Controller/Api/CountersApiController.php b/httpdocs/src/Controller/Api/CountersApiController.php
index 8832ef2..745aff4 100644
--- a/httpdocs/src/Controller/Api/CountersApiController.php
+++ b/httpdocs/src/Controller/Api/CountersApiController.php
@@ -58,9 +58,9 @@ class CountersApiController extends AbstractController
// if(!$workshop){
// return new JsonResponse(["Error"=>"403: Unauthorized"],403);
// }
- $trainer = $em->getRepository('App:Trainer')
+ $trainer = $em->getRepository('App:Supervisor')
->findOneBy(['id'=>$request->request->get('trainer')]);
- if (empty($trainer) || !($trainer instanceof \App\Entity\Trainer) ){
+ if (empty($trainer) || !($trainer instanceof \App\Entity\Supervisor) ){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
}
@@ -78,7 +78,7 @@ class CountersApiController extends AbstractController
}
}
foreach( $usuarios as $usuario){
- $ge = $em->getRepository('App:GreenEntrepreneur')
+ $ge = $em->getRepository('App:Licitador')
->findOneBy(['id'=>$usuario]);
$evento = new Calendario();
$evento->setTitulo($titulo);
diff --git a/httpdocs/src/Controller/Api/GuardarTareaApiNonAdminController.php b/httpdocs/src/Controller/Api/GuardarTareaApiNonAdminController.php
index 582ad45..d7cc161 100644
--- a/httpdocs/src/Controller/Api/GuardarTareaApiNonAdminController.php
+++ b/httpdocs/src/Controller/Api/GuardarTareaApiNonAdminController.php
@@ -49,7 +49,7 @@
->findOneBy(['hash'=>$hash]);
$user=$external->getGreenEntrepreneur();
$tarea=$external->getTarea();
- if (empty($user) || !($user instanceof \App\Entity\GreenEntrepreneur) ){
+ if (empty($user) || !($user instanceof \App\Entity\Licitador) ){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
}
$this->save($tarea, $request, $em, $user);
@@ -71,7 +71,7 @@
->findOneBy(['hash'=>$hash]);
$user=$external->getGreenEntrepreneur();
$tarea=$external->getTarea();
- if (empty($user) || !($user instanceof \App\Entity\GreenEntrepreneur) ){
+ if (empty($user) || !($user instanceof \App\Entity\Licitador) ){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
}
$preguntas = $tarea->getPreguntasId();
diff --git a/httpdocs/src/Controller/Api/PreguntasApiController.php b/httpdocs/src/Controller/Api/PreguntasApiController.php
index 4ea19e6..4b4da53 100644
--- a/httpdocs/src/Controller/Api/PreguntasApiController.php
+++ b/httpdocs/src/Controller/Api/PreguntasApiController.php
@@ -14,7 +14,7 @@
use App\Entity\Indicador;
use App\Entity\Bookmarks;
use \App\Entity\Goal;
- use App\Entity\GreenEntrepreneur;
+ use App\Entity\Licitador;
use App\Entity\Respuestas;
use Symfony\Component\HttpFoundation\JsonResponse;
use Doctrine\ORM\Query\ResultSetMapping;
@@ -38,7 +38,7 @@
*/
public function getPreguntasAction(Request $request)
{
- /** @var \App\Entity\GreenEntrepreneur $user */
+ /** @var \App\Entity\Licitador $user */
$user = $this->getUser();
if (empty($user)){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
@@ -98,7 +98,7 @@
*/
public function getEmailAction(Request $request)
{
- /** @var \App\Entity\GreenEntrepreneur $user */
+ /** @var \App\Entity\Licitador $user */
$user = $this->getUser();
if (empty($user)){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
@@ -136,7 +136,7 @@
*/
public function getTareasAction(Request $request )
{
- /** @var \App\Entity\GreenEntrepreneur $user */
+ /** @var \App\Entity\Licitador $user */
$user = $this->getUser();
if (empty($user)){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
@@ -506,14 +506,14 @@
*@return Response
*/
public function toggleBookmark($userId, $indicadorId){
- /** @var \App\Entity\GreenEntrepreneur $user */
+ /** @var \App\Entity\Licitador $user */
$user = $this->getUser();
if (empty($user)){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
}
$request = $this->requestStack->getCurrentRequest();
$em = $this->getDoctrine()->getManager();
- $ge = $em->getRepository('App:GreenEntrepreneur')
+ $ge = $em->getRepository('App:Licitador')
->findOneById($userId);
$indicador = $em->getRepository('App:Indicador')
->findOneById($indicadorId);
@@ -539,14 +539,14 @@
*@return Response
*/
public function toggleGoal($userId, $indicadorId){
- /** @var \App\Entity\GreenEntrepreneur $user */
+ /** @var \App\Entity\Licitador $user */
$user = $this->getUser();
if (empty($user)){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
}
$request = $this->requestStack->getCurrentRequest();
$em = $this->getDoctrine()->getManager();
- $ge = $em->getRepository('App:GreenEntrepreneur')
+ $ge = $em->getRepository('App:Licitador')
->findOneById($userId);
$indicador = $em->getRepository('App:Indicador')
->findOneById($indicadorId);
@@ -573,7 +573,7 @@
*@return Response
*/
public function addIndicator($userId){
- /** @var \App\Entity\GreenEntrepreneur $user */
+ /** @var \App\Entity\Licitador $user */
$user = $this->getUser();
if (empty($user)){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
@@ -583,7 +583,7 @@
return new JsonResponse(["Error"=>"400: Bad Request"],400);
}
$em = $this->getDoctrine()->getManager();
- $ge = $em->getRepository('App:GreenEntrepreneur')
+ $ge = $em->getRepository('App:Licitador')
->findOneById($userId);
$indicador=new Indicador();
$indicador->setGenerico(false);
@@ -602,7 +602,7 @@
*@return Response
*/
public function editGoal($goalId){
- /** @var \App\Entity\GreenEntrepreneur $user */
+ /** @var \App\Entity\Licitador $user */
$user = $this->getUser();
if (empty($user)){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
diff --git a/httpdocs/src/Controller/ChatController.php b/httpdocs/src/Controller/ChatController.php
index 4cbf970..8123d43 100644
--- a/httpdocs/src/Controller/ChatController.php
+++ b/httpdocs/src/Controller/ChatController.php
@@ -7,14 +7,14 @@ namespace App\Controller;
use App\Entity\Calendario;
use App\Entity\Comentarios;
use App\Entity\Convocatoria;
-use App\Entity\GreenEntrepreneur;
+use App\Entity\Licitador;
use App\Entity\Mensaje;
use App\Entity\Preguntas;
use App\Entity\Procesos;
use App\Entity\Respuestas;
use App\Entity\Sala;
use App\Entity\SalaLastAccess;
-use App\Entity\Trainer;
+use App\Entity\Supervisor;
use App\Entity\WorkShop;
use DateTime;
use Doctrine\ORM\EntityManagerInterface;
diff --git a/httpdocs/src/Controller/RegistrationFinancialActorController.php b/httpdocs/src/Controller/RegistrationFinancialActorController.php
index 981003b..9b84fc9 100644
--- a/httpdocs/src/Controller/RegistrationFinancialActorController.php
+++ b/httpdocs/src/Controller/RegistrationFinancialActorController.php
@@ -28,7 +28,7 @@ use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use FOS\UserBundle\Controller\RegistrationController;
-use App\Entity\FinancialActor;
+use App\Entity\Contable;
use App\Kernel;
use Symfony\Contracts\Translation\TranslatorInterface;
@@ -67,7 +67,7 @@ public function __construct(EventDispatcherInterface $eventDispatcher, FactoryIn
*/
public function registerAction(Request $request)
{
- $user = new FinancialActor();
+ $user = new Contable();
$user->setEnabled(false);
$event = new GetResponseUserEvent($user, $request);
@@ -207,7 +207,7 @@ public function __construct(EventDispatcherInterface $eventDispatcher, FactoryIn
private function updateUser($user, $request){
$em = $this->getDoctrine()->getManager();
$datos=$request->request->all();
- $data=$datos['FinancialActor'];
+ $data=$datos['Contable'];
echo print_r($data,true);
//Contact Details
$user->setFirstname($data['register_usuario']['firstname']);
diff --git a/httpdocs/src/Controller/RegistrationGreenEnterpreneurController.php b/httpdocs/src/Controller/RegistrationGreenEnterpreneurController.php
index 10cd9f3..c7a8dbf 100644
--- a/httpdocs/src/Controller/RegistrationGreenEnterpreneurController.php
+++ b/httpdocs/src/Controller/RegistrationGreenEnterpreneurController.php
@@ -30,7 +30,7 @@ use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use FOS\UserBundle\Controller\RegistrationController;
use Symfony\Component\Security\Core\Authentication\Token\UsernamePasswordToken;
use Symfony\Component\Security\Http\Event\InteractiveLoginEvent;
-use App\Entity\GreenEntrepreneur;
+use App\Entity\Licitador;
use App\Kernel;
use Symfony\Contracts\Translation\TranslatorInterface;
@@ -65,7 +65,7 @@ class RegistrationGreenEnterpreneurController extends Controller
*/
public function registerAction(Request $request)
{
- $user = new GreenEntrepreneur();
+ $user = new Licitador();
$user->setEnabled(true);
$event = new GetResponseUserEvent($user, $request);
diff --git a/httpdocs/src/Controller/RegistrationTrainerController.php b/httpdocs/src/Controller/RegistrationTrainerController.php
index 4ce6e25..ba6ef06 100644
--- a/httpdocs/src/Controller/RegistrationTrainerController.php
+++ b/httpdocs/src/Controller/RegistrationTrainerController.php
@@ -29,7 +29,7 @@ use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInt
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use FOS\UserBundle\Controller\RegistrationController;
use Doctrine\ORM\EntityManagerInterface;
-use App\Entity\Trainer;
+use App\Entity\Supervisor;
use App\Entity\Bso;
use App\Kernel;
use Symfony\Contracts\Translation\TranslatorInterface;
@@ -68,7 +68,7 @@ class RegistrationTrainerController extends Controller
*/
public function registerAction(Request $request)
{
- $user = new Trainer();
+ $user = new Supervisor();
$user->setEnabled(true);
$event = new GetResponseUserEvent($user, $request);
@@ -210,7 +210,7 @@ class RegistrationTrainerController extends Controller
private function updateUser($user, $request){
$datos=$request->request->all();
- $data=$datos['Trainer'];
+ $data=$datos['Supervisor'];
//echo print_r($data,true);
//Required Data
$user->setFirstname($data['datos_usuario']['firstname']);
diff --git a/httpdocs/src/Controller/TareaErrorController.php b/httpdocs/src/Controller/TareaErrorController.php
index 8f3b3dd..09abd7b 100644
--- a/httpdocs/src/Controller/TareaErrorController.php
+++ b/httpdocs/src/Controller/TareaErrorController.php
@@ -18,7 +18,7 @@ class TareaErrorController extends Controller
foreach($preguntas as $pregunta){
$mapPreguntas[]=$pregunta->getId();
}
- $usuario = $em->getRepository('App:GreenEntrepreneur')
+ $usuario = $em->getRepository('App:Licitador')
->findById(13);
$respuestas = $em->getRepository('App:Respuestas')
->findBy(['preguntas'=>$mapPreguntas, 'greenEntrepreneur'=> $usuario[0]->getId()]);
diff --git a/httpdocs/src/Entity/.gitignore b/httpdocs/src/Entity/.gitignore
deleted file mode 100644
index e69de29..0000000
diff --git a/httpdocs/src/Entity/Bookmarks.php b/httpdocs/src/Entity/Bookmarks.php
index 1e35b72..8c15413 100644
--- a/httpdocs/src/Entity/Bookmarks.php
+++ b/httpdocs/src/Entity/Bookmarks.php
@@ -3,7 +3,7 @@
namespace App\Entity;
use Doctrine\ORM\Mapping as ORM;
use App\Entity\Indicador;
- use App\Entity\GreenEntrepreneur;
+ use App\Entity\Licitador;
/**
* @ORM\Table(
@@ -34,7 +34,7 @@
private $indicador;
/**
- * @ORM\ManyToOne(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="indicadorUsuario",cascade={"persist"})
+ * @ORM\ManyToOne(targetEntity="App\Entity\Licitador", inversedBy="indicadorUsuario",cascade={"persist"})
* @ORM\JoinColumn(name="green_entrepreneur_id", referencedColumnName="id")
*/
private $greenEntrepreneur;
@@ -60,12 +60,12 @@
return $this;
}
- public function getGreenEntrepreneur(): ?GreenEntrepreneur
+ public function getGreenEntrepreneur(): ?Licitador
{
return $this->greenEntrepreneur;
}
- public function setGreenEntrepreneur(?GreenEntrepreneur $greenEntrepreneur): self
+ public function setGreenEntrepreneur(?Licitador $greenEntrepreneur): self
{
$this->greenEntrepreneur = $greenEntrepreneur;
diff --git a/httpdocs/src/Entity/BussinessStage.php b/httpdocs/src/Entity/BussinessStage.php
index 184d1e6..b75aebd 100644
--- a/httpdocs/src/Entity/BussinessStage.php
+++ b/httpdocs/src/Entity/BussinessStage.php
@@ -41,7 +41,7 @@ class BussinessStage extends AbstractPersonalTranslatable implements Translatabl
/**
- * @ORM\OneToMany(targetEntity="App\Entity\GreenEntrepreneur", mappedBy="bussiness_stage")
+ * @ORM\OneToMany(targetEntity="App\Entity\Licitador", mappedBy="bussiness_stage")
*/
private $greenEntrepreneurs;
@@ -91,7 +91,7 @@ class BussinessStage extends AbstractPersonalTranslatable implements Translatabl
return $this->greenEntrepreneurs;
}
- public function addGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function addGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if (!$this->greenEntrepreneurs->contains($greenEntrepreneur)) {
$this->greenEntrepreneurs->add($greenEntrepreneur);
@@ -100,7 +100,7 @@ class BussinessStage extends AbstractPersonalTranslatable implements Translatabl
return $this;
}
- public function removeGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function removeGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if ($this->greenEntrepreneurs->contains($greenEntrepreneur)) {
$this->greenEntrepreneurs->removeElement($greenEntrepreneur);
diff --git a/httpdocs/src/Entity/Comentarios.php b/httpdocs/src/Entity/Comentarios.php
index cedd79d..b4cfc7c 100644
--- a/httpdocs/src/Entity/Comentarios.php
+++ b/httpdocs/src/Entity/Comentarios.php
@@ -27,7 +27,7 @@ class Comentarios
private $fecha;
/**
- * @ORM\ManyToOne(targetEntity="App\Entity\Trainer", inversedBy="comentarios")
+ * @ORM\ManyToOne(targetEntity="App\Entity\Supervisor", inversedBy="comentarios")
* @ORM\JoinColumn(name="trainer_id", referencedColumnName="id", onDelete="NO ACTION")
*/
private $trainer;
@@ -77,12 +77,12 @@ class Comentarios
return $this;
}
- public function getTrainer(): ?Trainer
+ public function getTrainer(): ?Supervisor
{
return $this->trainer;
}
- public function setTrainer(?Trainer $trainer): self
+ public function setTrainer(?Supervisor $trainer): self
{
$this->trainer = $trainer;
diff --git a/httpdocs/src/Entity/FinancialActor.php b/httpdocs/src/Entity/Contable.php
similarity index 96%
rename from httpdocs/src/Entity/FinancialActor.php
rename to httpdocs/src/Entity/Contable.php
index 2cc643f..550e21d 100644
--- a/httpdocs/src/Entity/FinancialActor.php
+++ b/httpdocs/src/Entity/Contable.php
@@ -8,7 +8,7 @@ use Symfony\Component\Validator\Constraints as Assert;
/**
* @ORM\Entity(repositoryClass="App\Repository\FinancialActorRepository")
*/
-class FinancialActor extends \App\Entity\User
+class Contable extends \App\Entity\User
{
/**
* @ORM\Column(type="string", nullable=false)
@@ -109,7 +109,7 @@ class FinancialActor extends \App\Entity\User
private $investment_criteria;
/**
- * @ORM\ManyToMany(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="financials")
+ * @ORM\ManyToMany(targetEntity="App\Entity\Licitador", inversedBy="financials")
* @ORM\JoinTable(
* name="greenentrepreneursharedfiles",
* joinColumns={@ORM\JoinColumn(name="financial_actor_id", referencedColumnName="id", nullable=false)},
@@ -128,7 +128,7 @@ class FinancialActor extends \App\Entity\User
/**
- * @return Collection|GreenEntrepreneur[]
+ * @return Collection|Licitador[]
*/
public function getScopeOperations(): Collection
{
@@ -156,7 +156,7 @@ class FinancialActor extends \App\Entity\User
return $this;
}
/**
- * @return Collection|GreenEntrepreneur[]
+ * @return Collection|Licitador[]
*/
public function getGreenEntrepreneur(): Collection
{
@@ -164,7 +164,7 @@ class FinancialActor extends \App\Entity\User
}
- public function addGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function addGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if (!$this->greenEntrepreneur->contains($greenEntrepreneur)) {
$this->greenEntrepreneur[] = $greenEntrepreneur;
@@ -174,7 +174,7 @@ class FinancialActor extends \App\Entity\User
return $this;
}
- public function removeGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function removeGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if ($this->greenEntrepreneur->contains($greenEntrepreneur)) {
$this->greenEntrepreneur->removeElement($greenEntrepreneur);
diff --git a/httpdocs/src/Entity/Convocatoria.php b/httpdocs/src/Entity/Convocatoria.php
index 3f61142..aabd8d9 100644
--- a/httpdocs/src/Entity/Convocatoria.php
+++ b/httpdocs/src/Entity/Convocatoria.php
@@ -88,7 +88,7 @@ class Convocatoria
private $bso;
/**
- * @ORM\ManyToMany(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="convocatoria")
+ * @ORM\ManyToMany(targetEntity="App\Entity\Licitador", inversedBy="convocatoria")
* @ORM\JoinTable(
* name="GreenEnterPreneurConvocatoria",
* joinColumns={@ORM\JoinColumn(name="convocatoria_id", referencedColumnName="id", nullable=false)},
@@ -151,14 +151,14 @@ class Convocatoria
}
/**
- * @return Collection|GreenEntrepreneur[]
+ * @return Collection|Licitador[]
*/
public function getGreenEntrepreneur(): Collection
{
return $this->greenEntrepreneur;
}
- public function addGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function addGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if (!$this->greenEntrepreneur->contains($greenEntrepreneur)) {
$this->greenEntrepreneur[] = $greenEntrepreneur;
@@ -167,7 +167,7 @@ class Convocatoria
return $this;
}
- public function removeGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function removeGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if ($this->greenEntrepreneur->contains($greenEntrepreneur)) {
$this->greenEntrepreneur->removeElement($greenEntrepreneur);
diff --git a/httpdocs/src/Entity/Encuesta.php b/httpdocs/src/Entity/Encuesta.php
index f1d9ed6..49e3670 100644
--- a/httpdocs/src/Entity/Encuesta.php
+++ b/httpdocs/src/Entity/Encuesta.php
@@ -35,7 +35,7 @@ class Encuesta
/**
* @ORM\Id
- * @ORM\ManyToOne(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="formularioUsuario", cascade={"persist"})
+ * @ORM\ManyToOne(targetEntity="App\Entity\Licitador", inversedBy="formularioUsuario", cascade={"persist"})
* @ORM\JoinColumn(name="green_entrepreneur_id", referencedColumnName="id", onDelete="NO ACTION")
*/
private $greenEntrepreneur;
@@ -65,12 +65,12 @@ class Encuesta
- public function getGreenEntrepreneur(): ?GreenEntrepreneur
+ public function getGreenEntrepreneur(): ?Licitador
{
return $this->greenEntrepreneur;
}
- public function setGreenEntrepreneur(?GreenEntrepreneur $greenEntrepreneur): self
+ public function setGreenEntrepreneur(?Licitador $greenEntrepreneur): self
{
$this->greenEntrepreneur = $greenEntrepreneur;
diff --git a/httpdocs/src/Entity/Goal.php b/httpdocs/src/Entity/Goal.php
index 98080ad..7dd4e6f 100644
--- a/httpdocs/src/Entity/Goal.php
+++ b/httpdocs/src/Entity/Goal.php
@@ -3,7 +3,7 @@
namespace App\Entity;
use Doctrine\ORM\Mapping as ORM;
use App\Entity\Indicador;
- use App\Entity\GreenEntrepreneur;
+ use App\Entity\Licitador;
/**
* @ORM\Table(
@@ -34,7 +34,7 @@
private $indicador;
/**
- * @ORM\ManyToOne(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="goalUsuario",cascade={"persist"})
+ * @ORM\ManyToOne(targetEntity="App\Entity\Licitador", inversedBy="goalUsuario",cascade={"persist"})
* @ORM\JoinColumn(name="green_entrepreneur_id", referencedColumnName="id")
*/
private $greenEntrepreneur;
@@ -89,12 +89,12 @@
return $this;
}
- public function getGreenEntrepreneur(): ?GreenEntrepreneur
+ public function getGreenEntrepreneur(): ?Licitador
{
return $this->greenEntrepreneur;
}
- public function setGreenEntrepreneur(?GreenEntrepreneur $greenEntrepreneur): self
+ public function setGreenEntrepreneur(?Licitador $greenEntrepreneur): self
{
$this->greenEntrepreneur = $greenEntrepreneur;
diff --git a/httpdocs/src/Entity/Inscripcion.php b/httpdocs/src/Entity/Inscripcion.php
index 3939358..958b717 100644
--- a/httpdocs/src/Entity/Inscripcion.php
+++ b/httpdocs/src/Entity/Inscripcion.php
@@ -38,7 +38,7 @@ class Inscripcion
private $campo_3;
/**
- * @ORM\ManyToOne(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="inscripciones")
+ * @ORM\ManyToOne(targetEntity="App\Entity\Licitador", inversedBy="inscripciones")
* @ORM\JoinColumn(name="green_entrepreneur_id", referencedColumnName="id", nullable=false)
*/
private $greenEntrepreneur;
@@ -107,12 +107,12 @@ class Inscripcion
return $this;
}
- public function getGreenEntrepreneur(): ?GreenEntrepreneur
+ public function getGreenEntrepreneur(): ?Licitador
{
return $this->greenEntrepreneur;
}
- public function setGreenEntrepreneur(?GreenEntrepreneur $greenEntrepreneur): self
+ public function setGreenEntrepreneur(?Licitador $greenEntrepreneur): self
{
$this->greenEntrepreneur = $greenEntrepreneur;
diff --git a/httpdocs/src/Entity/GreenEntrepreneur.php b/httpdocs/src/Entity/Licitador.php
similarity index 97%
rename from httpdocs/src/Entity/GreenEntrepreneur.php
rename to httpdocs/src/Entity/Licitador.php
index 9170bc4..3f36df2 100644
--- a/httpdocs/src/Entity/GreenEntrepreneur.php
+++ b/httpdocs/src/Entity/Licitador.php
@@ -17,7 +17,7 @@ use App\Entity\Goal;
/**
* @ORM\Entity(repositoryClass="App\Repository\GreenEntrepreneurRepository")
*/
-class GreenEntrepreneur extends User
+class Licitador extends User
{
/**
* @ORM\ManyToOne(targetEntity="App\Entity\BussinessStage", inversedBy="greenEntrepreneurs")
@@ -80,12 +80,12 @@ class GreenEntrepreneur extends User
private $convocatoria;
/**
- * @ORM\ManyToMany(targetEntity="App\Entity\Trainer", mappedBy="greenEntrepreneur")
+ * @ORM\ManyToMany(targetEntity="App\Entity\Supervisor", mappedBy="greenEntrepreneur")
*/
private $trainer;
/**
- * @ORM\ManyToMany(targetEntity="App\Entity\FinancialActor", mappedBy="greenEntrepreneur")
+ * @ORM\ManyToMany(targetEntity="App\Entity\Contable", mappedBy="greenEntrepreneur")
*/
private $financials;
@@ -458,14 +458,14 @@ class GreenEntrepreneur extends User
}
/**
- * @return Collection|Trainer[]
+ * @return Collection|Supervisor[]
*/
public function getTrainer(): Collection
{
return $this->trainer;
}
- public function addTrainer(Trainer $trainer): self
+ public function addTrainer(Supervisor $trainer): self
{
if (!$this->trainer->contains($trainer)) {
$this->trainer[] = $trainer;
@@ -475,7 +475,7 @@ class GreenEntrepreneur extends User
return $this;
}
- public function removeTrainer(Trainer $trainer): self
+ public function removeTrainer(Supervisor $trainer): self
{
if ($this->trainer->contains($trainer)) {
$this->trainer->removeElement($trainer);
@@ -486,14 +486,14 @@ class GreenEntrepreneur extends User
}
/**
- * @return Collection|Trainer[]
+ * @return Collection|Supervisor[]
*/
public function getFinancials(): Collection
{
return $this->financials;
}
- public function addFinancial(FinancialActor $financialActor): self
+ public function addFinancial(Contable $financialActor): self
{
if (!$this->financials->contains($financialActor)) {
$this->financials[] = $financialActor;
@@ -503,7 +503,7 @@ class GreenEntrepreneur extends User
return $this;
}
- public function removeFinancial(FinancialActor $financialActor): self
+ public function removeFinancial(Contable $financialActor): self
{
if ($this->financials->contains($financialActor)) {
$this->financials->removeElement($financialActor);
diff --git a/httpdocs/src/Entity/Preguntas.php b/httpdocs/src/Entity/Preguntas.php
index 9cbc911..913bf1d 100644
--- a/httpdocs/src/Entity/Preguntas.php
+++ b/httpdocs/src/Entity/Preguntas.php
@@ -58,7 +58,7 @@ class Preguntas extends AbstractPersonalTranslatable implements TranslatableInte
*/
private $isEmail=0;
/**
- * Is marked to Trainer review
+ * Is marked to Supervisor review
* @ORM\Column( type="boolean", nullable=true)
*/
private $isRevisable=0;
diff --git a/httpdocs/src/Entity/PreguntasFormulario.php b/httpdocs/src/Entity/PreguntasFormulario.php
index 5eb3862..808ebfe 100644
--- a/httpdocs/src/Entity/PreguntasFormulario.php
+++ b/httpdocs/src/Entity/PreguntasFormulario.php
@@ -62,7 +62,7 @@ class PreguntasFormulario //extends Preguntas
*/
private $isEmail=0;
/**
- * Is marked to Trainer review
+ * Is marked to Supervisor review
* @ORM\Column( type="boolean", nullable=true)
*/
private $isRevisable=0;
diff --git a/httpdocs/src/Entity/ProcesoGreenEnterpreneur.php b/httpdocs/src/Entity/ProcesoGreenEnterpreneur.php
index 02834aa..6b18453 100644
--- a/httpdocs/src/Entity/ProcesoGreenEnterpreneur.php
+++ b/httpdocs/src/Entity/ProcesoGreenEnterpreneur.php
@@ -37,7 +37,7 @@
private $proceso;
/**
- * @ORM\ManyToOne(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="procesoUsuario",cascade={"persist"})
+ * @ORM\ManyToOne(targetEntity="App\Entity\Licitador", inversedBy="procesoUsuario",cascade={"persist"})
* @ORM\JoinColumn(name="green_entrepreneur_id", referencedColumnName="id",onDelete="NO ACTION")
*/
private $greenEntrepreneur;
@@ -84,12 +84,12 @@
return $this;
}
- public function getGreenEntrepreneur(): ?GreenEntrepreneur
+ public function getGreenEntrepreneur(): ?Licitador
{
return $this->greenEntrepreneur;
}
- public function setGreenEntrepreneur(?GreenEntrepreneur $greenEntrepreneur): self
+ public function setGreenEntrepreneur(?Licitador $greenEntrepreneur): self
{
$this->greenEntrepreneur = $greenEntrepreneur;
diff --git a/httpdocs/src/Entity/Respuestas.php b/httpdocs/src/Entity/Respuestas.php
index 1ea3d0b..3dca030 100644
--- a/httpdocs/src/Entity/Respuestas.php
+++ b/httpdocs/src/Entity/Respuestas.php
@@ -44,7 +44,7 @@ class Respuestas
/**
* @ORM\Id
- * @ORM\ManyToOne(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="respuestas")
+ * @ORM\ManyToOne(targetEntity="App\Entity\Licitador", inversedBy="respuestas")
* @ORM\JoinColumn(name="green_entrepreneur_id", referencedColumnName="id", nullable=false, onDelete="NO ACTION")
*/
private $greenEntrepreneur;
@@ -179,12 +179,12 @@ class Respuestas
}
- public function getGreenEntrepreneur(): ?GreenEntrepreneur
+ public function getGreenEntrepreneur(): ?Licitador
{
return $this->greenEntrepreneur;
}
- public function setGreenEntrepreneur(?GreenEntrepreneur $greenEntrepreneur): self
+ public function setGreenEntrepreneur(?Licitador $greenEntrepreneur): self
{
$this->greenEntrepreneur = $greenEntrepreneur;
diff --git a/httpdocs/src/Entity/RespuestasFormulario.php b/httpdocs/src/Entity/RespuestasFormulario.php
index 69354db..b037fe7 100644
--- a/httpdocs/src/Entity/RespuestasFormulario.php
+++ b/httpdocs/src/Entity/RespuestasFormulario.php
@@ -34,7 +34,7 @@ class RespuestasFormulario
private $convocatoria;
/**
* @ORM\Id
- * @ORM\ManyToOne(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="respuestasformulario")
+ * @ORM\ManyToOne(targetEntity="App\Entity\Licitador", inversedBy="respuestasformulario")
* @ORM\JoinColumn(name="green_entrepreneur_id", referencedColumnName="id", nullable=false, onDelete="NO ACTION")
*/
private $greenEntrepreneur;
@@ -81,12 +81,12 @@ class RespuestasFormulario
- public function getGreenEntrepreneur(): ?GreenEntrepreneur
+ public function getGreenEntrepreneur(): ?Licitador
{
return $this->greenEntrepreneur;
}
- public function setGreenEntrepreneur(?GreenEntrepreneur $greenEntrepreneur): self
+ public function setGreenEntrepreneur(?Licitador $greenEntrepreneur): self
{
$this->greenEntrepreneur = $greenEntrepreneur;
diff --git a/httpdocs/src/Entity/Sector.php b/httpdocs/src/Entity/Sector.php
index 56f3efe..200a2d6 100644
--- a/httpdocs/src/Entity/Sector.php
+++ b/httpdocs/src/Entity/Sector.php
@@ -36,11 +36,11 @@
*/
private $indicadores;
/**
- * @ORM\OneToMany(targetEntity="App\Entity\GreenEntrepreneur", mappedBy="sector")
+ * @ORM\OneToMany(targetEntity="App\Entity\Licitador", mappedBy="sector")
*/
private $greenEntrepreneurs;
/**
- * @ORM\ManyToMany(targetEntity="App\Entity\FinancialActor", mappedBy="scope_operations")
+ * @ORM\ManyToMany(targetEntity="App\Entity\Contable", mappedBy="scope_operations")
*/
private $financialactor;
@@ -70,7 +70,7 @@
return $this->id;
}
/**
- * @return Collection|GreenEntrepreneur[]
+ * @return Collection|Licitador[]
*/
public function getFinancialactor(): Collection
{
@@ -78,7 +78,7 @@
}
- public function addFinancialactor(FinancialActor $fa): self
+ public function addFinancialactor(Contable $fa): self
{
if (!$this->financialactor->contains($fa)) {
$this->financialactor[] = $fa;
@@ -88,7 +88,7 @@
return $this;
}
- public function removeFinancialactor(FinancialActor $fa): self
+ public function removeFinancialactor(Contable $fa): self
{
if ($this->financialactor->contains($fa)) {
$this->financialactor->removeElement($fa);
@@ -143,7 +143,7 @@
return $this->greenEntrepreneurs;
}
- public function addGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function addGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if (!$this->greenEntrepreneurs->contains($greenEntrepreneur)) {
$this->greenEntrepreneurs->add($greenEntrepreneur);
@@ -152,7 +152,7 @@
return $this;
}
- public function removeGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function removeGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if ($this->greenEntrepreneurs->contains($greenEntrepreneur)) {
$this->greenEntrepreneurs->removeElement($greenEntrepreneur);
diff --git a/httpdocs/src/Entity/Trainer.php b/httpdocs/src/Entity/Supervisor.php
similarity index 95%
rename from httpdocs/src/Entity/Trainer.php
rename to httpdocs/src/Entity/Supervisor.php
index 531ddc9..9eee298 100644
--- a/httpdocs/src/Entity/Trainer.php
+++ b/httpdocs/src/Entity/Supervisor.php
@@ -9,7 +9,7 @@ use FOS\UserBundle\Model\GroupInterface as Group;
/**
* @ORM\Entity(repositoryClass="App\Repository\TrainerRepository")
*/
-class Trainer extends \App\Entity\User
+class Supervisor extends \App\Entity\User
{
/**
* @ORM\Column(type="array", nullable=false)
@@ -50,7 +50,7 @@ class Trainer extends \App\Entity\User
$this->activities = $activities;
}
/**
- * @ORM\ManyToMany(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="trainer")
+ * @ORM\ManyToMany(targetEntity="App\Entity\Licitador", inversedBy="trainer")
* @ORM\JoinTable(
* name="GreenEntrepreneurHasTrainer",
* joinColumns={@ORM\JoinColumn(name="trainer_id", referencedColumnName="id", nullable=false)},
@@ -114,7 +114,7 @@ class Trainer extends \App\Entity\User
}
/**
- * @return Collection|GreenEntrepreneur[]
+ * @return Collection|Licitador[]
*/
public function getGreenEntrepreneur(): Collection
{
@@ -190,7 +190,7 @@ class Trainer extends \App\Entity\User
return $this;
}
- public function addGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function addGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if (!$this->greenEntrepreneur->contains($greenEntrepreneur)) {
$this->greenEntrepreneur[] = $greenEntrepreneur;
@@ -199,7 +199,7 @@ class Trainer extends \App\Entity\User
return $this;
}
- public function removeGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function removeGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if ($this->greenEntrepreneur->contains($greenEntrepreneur)) {
$this->greenEntrepreneur->removeElement($greenEntrepreneur);
diff --git a/httpdocs/src/Entity/TareaGreenEnterpreneur.php b/httpdocs/src/Entity/TareaGreenEnterpreneur.php
index a8e6814..16d0406 100644
--- a/httpdocs/src/Entity/TareaGreenEnterpreneur.php
+++ b/httpdocs/src/Entity/TareaGreenEnterpreneur.php
@@ -31,7 +31,7 @@ class TareaGreenEnterpreneur
/**
* @ORM\Id
- * @ORM\ManyToOne(targetEntity="App\Entity\GreenEntrepreneur", inversedBy="tareaUsuario", cascade={"persist"})
+ * @ORM\ManyToOne(targetEntity="App\Entity\Licitador", inversedBy="tareaUsuario", cascade={"persist"})
* @ORM\JoinColumn(name="green_entrepreneur_id", referencedColumnName="id", onDelete="NO ACTION")
*/
private $greenEntrepreneur;
@@ -71,12 +71,12 @@ class TareaGreenEnterpreneur
return $this;
}
- public function getGreenEntrepreneur(): ?GreenEntrepreneur
+ public function getGreenEntrepreneur(): ?Licitador
{
return $this->greenEntrepreneur;
}
- public function setGreenEntrepreneur(?GreenEntrepreneur $greenEntrepreneur): self
+ public function setGreenEntrepreneur(?Licitador $greenEntrepreneur): self
{
$this->greenEntrepreneur = $greenEntrepreneur;
diff --git a/httpdocs/src/Entity/User.php b/httpdocs/src/Entity/User.php
index d8aa3ee..0c3f59f 100644
--- a/httpdocs/src/Entity/User.php
+++ b/httpdocs/src/Entity/User.php
@@ -27,10 +27,10 @@ use Vich\UploaderBundle\Mapping\Annotation as Vich;
* @ORM\DiscriminatorColumn(name="type", type="string")
* @ORM\DiscriminatorMap({
* "backend_user":"App\Entity\User",
- * "green_entrepreneur":"App\Entity\GreenEntrepreneur",
+ * "green_entrepreneur":"App\Entity\Licitador",
* "bso":"App\Entity\Bso",
- * "trainer":"App\Entity\Trainer",
- * "financial_actor":"App\Entity\FinancialActor"
+ * "trainer":"App\Entity\Supervisor",
+ * "financial_actor":"App\Entity\Contable"
* })
* @Vich\Uploadable
*/
diff --git a/httpdocs/src/Entity/WorkShop.php b/httpdocs/src/Entity/WorkShop.php
index bc832f4..4e62de8 100644
--- a/httpdocs/src/Entity/WorkShop.php
+++ b/httpdocs/src/Entity/WorkShop.php
@@ -59,7 +59,7 @@ class WorkShop
private $sala;
/**
- * @ORM\ManyToMany(targetEntity="App\Entity\Trainer", inversedBy="workShop")
+ * @ORM\ManyToMany(targetEntity="App\Entity\Supervisor", inversedBy="workShop")
* @ORM\JoinColumn(name="trainer_id", referencedColumnName="id")
* @Assert\NotBlank()
* @Assert\Valid()
@@ -79,7 +79,7 @@ class WorkShop
private $procesos;
/**
- * @ORM\ManyToMany(targetEntity="App\Entity\GreenEntrepreneur", mappedBy="workShop", cascade={"persist"})
+ * @ORM\ManyToMany(targetEntity="App\Entity\Licitador", mappedBy="workShop", cascade={"persist"})
*/
private $greenEntrepreneur;
@@ -184,14 +184,14 @@ class WorkShop
return $this;
}
/**
- * @return Collection|Trainer[]
+ * @return Collection|Supervisor[]
*/
public function getTrainer(): Collection
{
return $this->trainer;
}
- public function addTrainer(Trainer $trainer): self
+ public function addTrainer(Supervisor $trainer): self
{
if (!$this->trainer->contains($trainer)) {
$this->trainer->add($trainer);
@@ -201,7 +201,7 @@ class WorkShop
return $this;
}
- public function removeTrainer(Trainer $trainer): self
+ public function removeTrainer(Supervisor $trainer): self
{
if ($this->trainer->contains($trainer)) {
$this->trainer->removeElement($trainer);
@@ -242,14 +242,14 @@ class WorkShop
}
/**
- * @return Collection|GreenEntrepreneur[]
+ * @return Collection|Licitador[]
*/
public function getGreenEntrepreneur(): Collection
{
return $this->greenEntrepreneur;
}
- public function addGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function addGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if (!$this->greenEntrepreneur->contains($greenEntrepreneur)) {
$this->greenEntrepreneur->add($greenEntrepreneur);
@@ -259,7 +259,7 @@ class WorkShop
return $this;
}
- public function removeGreenEntrepreneur(GreenEntrepreneur $greenEntrepreneur): self
+ public function removeGreenEntrepreneur(Licitador $greenEntrepreneur): self
{
if ($this->greenEntrepreneur->contains($greenEntrepreneur)) {
$this->greenEntrepreneur->removeElement($greenEntrepreneur);
diff --git a/httpdocs/src/Form/Type/RegistrationFinancialActorFormType.php b/httpdocs/src/Form/Type/RegistrationFinancialActorFormType.php
index e0eb54b..3ad6eb4 100644
--- a/httpdocs/src/Form/Type/RegistrationFinancialActorFormType.php
+++ b/httpdocs/src/Form/Type/RegistrationFinancialActorFormType.php
@@ -3,7 +3,7 @@
namespace App\Form\Type;
use AdamQuaile\Bundle\FieldsetBundle\Form\FieldsetType;
-use App\Entity\FinancialActor;
+use App\Entity\Contable;
use App\Entity\Sector;
use Sonata\Form\Type\DatePickerType;
use Sonata\UserBundle\Model\UserInterface;
@@ -36,7 +36,7 @@ class RegistrationFinancialActorFormType extends RegistrationFormType
/**
* @param string $class The User class name
*/
- public function __construct(string $class='FinancialActor')
+ public function __construct(string $class='Contable')
{
$this->class = $class;
}
@@ -209,7 +209,7 @@ class RegistrationFinancialActorFormType extends RegistrationFormType
{
$resolver->setDefaults(
[
- 'data_class' => 'App\Entity\FinancialActor'
+ 'data_class' => 'App\Entity\Contable'
]
);
}
diff --git a/httpdocs/src/Form/Type/RegistrationGreenEnterpreneurFormType.php b/httpdocs/src/Form/Type/RegistrationGreenEnterpreneurFormType.php
index 4b2f675..30ec0cb 100644
--- a/httpdocs/src/Form/Type/RegistrationGreenEnterpreneurFormType.php
+++ b/httpdocs/src/Form/Type/RegistrationGreenEnterpreneurFormType.php
@@ -35,7 +35,7 @@ class RegistrationGreenEnterpreneurFormType extends AbstractType
/**
* @param string $class The User class name
*/
- public function __construct(string $class='GreenEntrepreneur')
+ public function __construct(string $class='Licitador')
{
$this->class = $class;
}
@@ -190,7 +190,7 @@ class RegistrationGreenEnterpreneurFormType extends AbstractType
{
$resolver->setDefaults(
[
- 'data_class' => 'App\Entity\GreenEntrepreneur'
+ 'data_class' => 'App\Entity\Licitador'
]
);
}
diff --git a/httpdocs/src/Form/Type/RegistrationTrainerFormType.php b/httpdocs/src/Form/Type/RegistrationTrainerFormType.php
index 5f377d5..57afa3f 100644
--- a/httpdocs/src/Form/Type/RegistrationTrainerFormType.php
+++ b/httpdocs/src/Form/Type/RegistrationTrainerFormType.php
@@ -34,7 +34,7 @@ class RegistrationTrainerFormType extends AbstractType
/**
* @param string $class The User class name
*/
- public function __construct(string $class= 'Trainer')
+ public function __construct(string $class= 'Supervisor')
{
$this->class = $class;
}
@@ -166,7 +166,7 @@ class RegistrationTrainerFormType extends AbstractType
{
$resolver->setDefaults(
[
- 'data_class' => 'App\Entity\Trainer'
+ 'data_class' => 'App\Entity\Supervisor'
]
);
}
diff --git a/httpdocs/src/Repository/FinancialActorRepository.php b/httpdocs/src/Repository/FinancialActorRepository.php
index d18b7b7..3df432c 100644
--- a/httpdocs/src/Repository/FinancialActorRepository.php
+++ b/httpdocs/src/Repository/FinancialActorRepository.php
@@ -2,7 +2,7 @@
namespace App\Repository;
-use App\Entity\GreenEntrepreneur;
+use App\Entity\Licitador;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Common\Persistence\ManagerRegistry;
use Doctrine\ORM\EntityRepository;
diff --git a/httpdocs/src/Repository/GreenEntrepreneurRepository.php b/httpdocs/src/Repository/GreenEntrepreneurRepository.php
index fdf35ff..b5a6a03 100644
--- a/httpdocs/src/Repository/GreenEntrepreneurRepository.php
+++ b/httpdocs/src/Repository/GreenEntrepreneurRepository.php
@@ -2,7 +2,7 @@
namespace App\Repository;
-use App\Entity\GreenEntrepreneur;
+use App\Entity\Licitador;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Common\Persistence\ManagerRegistry;
@@ -10,7 +10,7 @@ class GreenEntrepreneurRepository extends ServiceEntityRepository
{
public function __construct(ManagerRegistry $registry)
{
- parent::__construct($registry, GreenEntrepreneur::class);
+ parent::__construct($registry, Licitador::class);
}
public function findCasoEstudio($language){
return $this->createQueryBuilder('ge')->where('username = :username')
diff --git a/httpdocs/src/Resources/SonataAdminBundle/views/CRUD/list__action_share_files.html.twig b/httpdocs/src/Resources/SonataAdminBundle/views/CRUD/list__action_share_files.html.twig
index dda6ddf..2130e45 100644
--- a/httpdocs/src/Resources/SonataAdminBundle/views/CRUD/list__action_share_files.html.twig
+++ b/httpdocs/src/Resources/SonataAdminBundle/views/CRUD/list__action_share_files.html.twig
@@ -9,7 +9,7 @@ file that was distributed with this source code.
#}
-{% if instanceof(object, "\\App\\Entity\\FinancialActor") %}
+{% if instanceof(object, "\\App\\Entity\\Contable") %}
{% if pregunta.isRevisable %}
{{ comentarios[pregunta.alias].comentario|raw }}
{{ comentarios[pregunta.alias].comentario|raw }}
{{ comentarios[pregunta.alias].comentario|raw }}
{{ comentarios[pregunta.alias].comentario|raw }}
diff --git a/httpdocs/src/Controller/Api/GuardarTareaApiController.php b/httpdocs/src/Controller/Api/GuardarTareaApiController.php
index 491821f..f9c1841 100644
--- a/httpdocs/src/Controller/Api/GuardarTareaApiController.php
+++ b/httpdocs/src/Controller/Api/GuardarTareaApiController.php
@@ -5,7 +5,7 @@
use App\Controller\ChatController;
use App\Entity\Comentarios;
use App\Entity\ComentariosHistorico;
- use App\Entity\GreenEntrepreneur;
+ use App\Entity\Licitador;
use App\Entity\Respuestas;
use App\Entity\RespuestasHistoricas;
use App\Traits\SaveTasks;
@@ -69,7 +69,7 @@ $this->translator = $translator;
$em = $this->getDoctrine()->getManager();
$tarea = $em->getRepository('App:Tarea')
->findOneById($id);
- /** @var \App\Entity\GreenEntrepreneur $user */
+ /** @var \App\Entity\Licitador $user */
$user = $this->getUser();
if (empty($user) ){
@@ -81,7 +81,7 @@ $this->translator = $translator;
$res['error'] = 'Unidentified Green Entrepreneur';
return $this->renderWithExtraParams('admin/errorprecondition_view.html.twig', ['tarea' => $tarea, 'error' => $res['error']]);
}
- $ge = $em->getRepository('App:GreenEntrepreneur')->findOneById([$request->request->get('ge')]);
+ $ge = $em->getRepository('App:Licitador')->findOneById([$request->request->get('ge')]);
$this->savetrainer($tarea, $request, $em, $ge);
break;
case 'green_entrepreneur':
@@ -107,7 +107,7 @@ $this->translator = $translator;
->findOneBy(['hash'=>$hash]);
$user=$external->getGreenEntrepreneur();
$tarea=$external->getTarea();
- if (empty($user) || !($user instanceof \App\Entity\GreenEntrepreneur) ){
+ if (empty($user) || !($user instanceof \App\Entity\Licitador) ){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
}
$this->save($tarea, $request, $em, $user);
@@ -129,7 +129,7 @@ $this->translator = $translator;
->findOneBy(['hash'=>$hash]);
$user=$external->getGreenEntrepreneur();
$tarea=$external->getTarea();
- if (empty($user) || !($user instanceof \App\Entity\GreenEntrepreneur) ){
+ if (empty($user) || !($user instanceof \App\Entity\Licitador) ){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
}
$preguntas = $tarea->getPreguntasId();
@@ -213,15 +213,15 @@ $this->translator = $translator;
$pregunta=$em->getRepository('App:Preguntas')->findOneById((int)$id);
$template=$pregunta->getTarea()->getTemplateId()->getEmailfilename();
- /** @var \App\Entity\GreenEntrepreneur $user */
+ /** @var \App\Entity\Licitador $user */
$user = $this->getUser();
//Nos aseguramos que es un GreenEntrepreneur
if (empty($user)){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
}else{
- $user=$em->getRepository('App:GreenEntrepreneur')->findOneById((int)$user->getId());
+ $user=$em->getRepository('App:Licitador')->findOneById((int)$user->getId());
if (empty($user)) {
return new JsonResponse(["Error" => "401: Unauthorized"], 401);
}
@@ -342,11 +342,11 @@ $this->translator = $translator;
$template = 'financialtool/email-results.html.twig';
- /** @var \App\Entity\GreenEntrepreneur $user */
+ /** @var \App\Entity\Licitador $user */
$user = $this->getUser();
- //Nos aseguramos que es un GreenEntrepreneur
- if (empty($user) || !($user instanceof GreenEntrepreneur)){
+ //Nos aseguramos que es un Licitador
+ if (empty($user) || !($user instanceof Licitador)){
throw new AccessDeniedHttpException();
}
@@ -213,15 +213,15 @@ $this->translator = $translator;
$user = $this->getUser();
- //Nos aseguramos que es un GreenEntrepreneur
+ //Nos aseguramos que es un Licitador
if (empty($user)){
return new JsonResponse(["Error"=>"401: Unauthorized"],401);
diff --git a/httpdocs/src/Entity/Bso.php b/httpdocs/src/Entity/Servicio.php
similarity index 94%
rename from httpdocs/src/Entity/Bso.php
rename to httpdocs/src/Entity/Servicio.php
index d278118..48dbfc7 100644
--- a/httpdocs/src/Entity/Bso.php
+++ b/httpdocs/src/Entity/Servicio.php
@@ -10,12 +10,12 @@ use Doctrine\ORM\Mapping as ORM;
/**
* @ORM\Entity
*/
-class Bso extends \App\Entity\User
+class Servicio extends \App\Entity\User
{
/**
* @ORM\Column(type="string", nullable=false)
* @Assert\NotBlank(message="Nombre de la compañia no puede estar en blanco")
* @Assert\Length(
* min = 2,
* max = 255,
@@ -60,7 +60,7 @@ class Bso extends \App\Entity\User
private $news;
/**
- * @ORM\ManyToMany(targetEntity="App\Entity\Trainer", mappedBy="bso")
+ * @ORM\ManyToMany(targetEntity="App\Entity\Supervisor", mappedBy="bso")
*/
private $trainer;
@@ -137,14 +137,14 @@ class Bso extends \App\Entity\User
}
/**
- * @return Collection|Trainer[]
+ * @return Collection|Supervisor[]
*/
public function getTrainer(): Collection
{
return $this->trainer;
}
- public function addTrainer(Trainer $trainer): self
+ public function addTrainer(Supervisor $trainer): self
{
if (!$this->trainer->contains($trainer)) {
$this->trainer[] = $trainer;
@@ -155,7 +155,7 @@ class Bso extends \App\Entity\User
return $this;
}
- public function removeTrainer(Trainer $trainer): self
+ public function removeTrainer(Supervisor $trainer): self
{
if ($this->trainer->contains($trainer)) {
$this->trainer->removeElement($trainer);
@@ -10,12 +10,12 @@ use Doctrine\ORM\Mapping as ORM;
/**
* @ORM\Column(type="string", nullable=false)
- * @Assert\NotBlank(message="Nombre de la compañia no puede estar en blanco")
+ * @Assert\NotBlank(message="Nombre del servicio no puede estar en blanco")
* @Assert\Length(
* min = 2,